==> dimples-0.5.8.tar.gz: dimples-0.5.8/dimples/edge/__init__.py <==
# -*- coding: utf-8 -*-
#
#   DIME : DIM Edge
#
#                                Written in 2022 by Moky <albert.moky@gmail.com>
#
# ==============================================================================
# MIT License
#
# Copyright (c) 2022 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================


"""
    DIM Edges for Stations
    ~~~~~~~~~~~~~~~~~~~~~~

                //===========\\
                ||           ||
                ||  Station  ||
      (Edge)....||           ||.....(Edge)
           :    \\===========//      :
           :                         :
    //===========\\           //===========\\
    ||           ||           ||           ||
    ||  Station  ||           ||  Station  ||
    ||           ||           ||           ||
    \\===========//           \\===========//
"""

from .octopus import OctopusMessenger
from .octopus import InnerMessenger, OuterMessenger
from .octopus import Octopus


__all__ = [

    'OctopusMessenger',
    'InnerMessenger', 'OuterMessenger',
    'Octopus',
]

==> dimples-1.3.2.tar.gz: dimples-1.3.2/dimples/edge/__init__.py <==
# -*- coding: utf-8 -*-
#
#   DIME : DIM Edge
#
#                                Written in 2022 by Moky <albert.moky@gmail.com>
#
# ==============================================================================
# MIT License
#
# Copyright (c) 2022 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================


"""
    DIM Edges for Stations
    ~~~~~~~~~~~~~~~~~~~~~~

                //===========\\
                ||           ||
                ||  Station  ||
      (Edge)....||           ||.....(Edge)
           :    \\===========//      :
           :                         :
    //===========\\           //===========\\
    ||           ||           ||           ||
    ||  Station  ||           ||  Station  ||
    ||           ||           ||           ||
    \\===========//           \\===========//
"""

from .octopus import Octopus

from .messenger import OctopusMessenger
from .messenger import InnerMessenger, OuterMessenger


__all__ = [

    'Octopus',

    'OctopusMessenger',
    'InnerMessenger', 'OuterMessenger',

]
